pub struct SideEffectsCache { /* private fields */ }Expand description
Cache for package build outputs (side effects of install scripts). After a package runs its install scripts (preinstall, install, postinstall), the resulting output is cached keyed by (package, version, platform, arch).
Implementations
Sourceimpl SideEffectsCache
impl SideEffectsCache
Sourcepub fn new(base_dir: Option<PathBuf>) -> Self
pub fn new(base_dir: Option<PathBuf>) -> Self
Create a new SideEffectsCache, storing cached outputs under the given directory.
Sourcepub fn has(&self, package_name: &str, version: &str) -> bool
pub fn has(&self, package_name: &str, version: &str) -> bool
Check if side effects are cached for a given package.
Sourcepub fn store(
&self,
package_name: &str,
version: &str,
package_dir: &Path,
) -> Result<()>
pub fn store( &self, package_name: &str, version: &str, package_dir: &Path, ) -> Result<()>
Store the side effects (built output) for a package.
package_dir is the directory of the installed package after scripts ran.