pub struct LinkProgress {
pub total: AtomicUsize,
pub completed: AtomicUsize,
}Expand description
Shared progress counter that can be polled from another thread.
The linker increments completed atomically as packages are linked.
Fields
total: AtomicUsizecompleted: AtomicUsizeImplementations